#!/bin/bash

# Run without parameters to load option sets from /etc/php-cleaner/php-cleaner.d
# Specify the path to file to source options from it

# Options:
# PHP_EXECUTABLE: path to php (wildcards supported)
# SESS_LIFETIME: session lifetime in seconds (default: 604800 = 1w)

LOGFILE="/var/log/php-session-cleaner.log"
CONF_D_DIR="/etc/php-cleaner/php-cleaner.d"

SCRIPT_DIR=$( cd -- "$( dirname -- "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )
SCRIPT_ABSPATH=${SCRIPT_DIR}/$(basename $0)

DEFAULT_SESS_LIFETIME=604800

function process_config_file() {
# $1: config file path

   echo "Processing config $1" >> $LOGFILE 
   source $1
   if [[ -n $PHP_EXECUTABLE ]]; then
      echo "PHP_EXECUTABLE: ${PHP_EXECUTABLE}" >> $LOGFILE
   else 
      echo "No PHP_EXECUTABLE set, aborting." >> $LOGFILE
      exit 1
   fi
   if [[ -n $SESS_LIFETIME ]]; then
      echo "SESS_LIFETIME: ${SESS_LIFETIME}" >> $LOGFILE
   else
      echo "No SESS_LIFETIME set, using default value (${DEFAULT_SESS_LIFETIME})." >> $LOGFILE
      SESS_LIFETIME=${DEFAULT_SESS_LIFETIME}
   fi

   PHPLIST=(${PHP_EXECUTABLE})
   for PHP in ${PHPLIST[@]}; do
     if ! [[ -x ${PHP} ]]; then
        echo "No executable ${PHP}, skipping" >> $LOGFILE
        continue
     fi

     SESS_LOCATION=$(${PHP} -r "echo session_save_path();")
     if ! [[ -d ${SESS_LOCATION} ]]; then
        echo "${SESS_LOCATION} is specified as session_save_path for ${PHP}, but it doesn't exists. Skipping" >> $LOGFILE
        continue
     fi

     echo "Using ${PHP} executable with ${SESS_LOCATION} session_save_path."  >> $LOGFILE

     CLEANED_LIST=$(find $SESS_LOCATION -type f -not -newermt "$SESS_LIFETIME seconds ago" -delete -print)
     if [[ "$CLEANED_LIST" == "" ]]; then
       echo "No sessions to clean." >> $LOGFILE
     else
       echo "Cleaned $(echo $CLEANED_LIST | wc -l) session(s)." >> $LOGFILE
     fi
   done
}

echo "=============================================" >> $LOGFILE
echo "Starting php-cleaner ($(date))" >> $LOGFILE 

if [[ $# -eq 0 ]]; then
  echo "No parameters specified, using config files from ${CONF_D_DIR}" >> $LOGFILE
  CONFIG_LIST=$(find ${CONF_D_DIR} -type f)
  if [[ -z ${CONFIG_LIST} ]]; then
    echo "${CONFIG_LIST} is empty, aborting" >> $LOGFILE
    exit 2
  fi
  for CONFIG_FILE in "${CONFIG_LIST}"; do
    "${SCRIPT_ABSPATH}" "${CONFIG_FILE}"
  done
else
  process_config_file "$1"
fi